@@ -10,4 +10,4 @@ def configure(parent):
     """
     Bind settings to upstream application main config
     """
-    settings.set_parent(ref)
+    settings.set_parent(parent)
